summaryrefslogtreecommitdiff
path: root/Master/tlpkg/TeXLive/TLUtils.pm
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2020-07-07 22:32:40 +0000
committerKarl Berry <karl@freefriends.org>2020-07-07 22:32:40 +0000
commit6503c193074ebc299da69a7faba0de5acf65c57e (patch)
treede85f171e4306bdb19476510d45c96b175244731 /Master/tlpkg/TeXLive/TLUtils.pm
parent45040ed7b1fe3cc98a2fd42254d197a20b1d9792 (diff)
11.x -> x86_64-darwin
git-svn-id: svn://tug.org/texlive/trunk@55776 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/tlpkg/TeXLive/TLUtils.pm')
-rw-r--r--Master/tlpkg/TeXLive/TLUtils.pm16
1 files changed, 9 insertions, 7 deletions
diff --git a/Master/tlpkg/TeXLive/TLUtils.pm b/Master/tlpkg/TeXLive/TLUtils.pm
index bc20471ea16..dfec74f6fd9 100644
--- a/Master/tlpkg/TeXLive/TLUtils.pm
+++ b/Master/tlpkg/TeXLive/TLUtils.pm
@@ -341,10 +341,9 @@ sub platform_name {
if ($OS eq "darwin") {
# We have two versions of Mac binary sets.
# 10.10/Yosemite and newer (Yosemite specially left over):
# -> x86_64-darwin [MacTeX]
# 10.6/Snow Leopard through 10.10/Yosemite:
# -> x86_64-darwinlegacy if 64-bit
#
# (BTW, uname -r numbers are larger by 4 than the Mac minor version.
# We don't use uname numbers here.)
@@ -356,13 +355,16 @@ sub platform_name {
# returns "10.x" values), and sysctl (processor hardware).
chomp (my $sw_vers = `sw_vers -productVersion`);
my ($os_major,$os_minor) = split (/\./, $sw_vers);
- if ($os_major != 10) {
+ if ($os_major < 10) {
warn "$0: only MacOSX is supported, not $OS $os_major.$os_minor "
. " (from sw_vers -productVersion: $sw_vers)\n";
return "unknownmac-unknownmac";
}
- if ($os_minor >= $mactex_darwin) {
- ; # current version, default is ok (x86_64-darwin).
+ if ($os_major >= 11) {
+ $CPU = "x86_64";
+ $OS = "darwin";
+ } elsif ($os_minor >= $mactex_darwin) {
+ ; # sufficiently new 10.x, default is ok (x86_64-darwin).
} elsif ($os_minor >= 6 && $os_minor < $mactex_darwin) {
# in between, x86 hardware only. On 10.6 only, must check if 64-bit,
# since if later than that, always 64-bit.
@@ -341,10 +341,9 @@ sub platform_name {
if ($OS eq "darwin") {
# We have two versions of Mac binary sets.
- # 10.10/Yosemite and newer (Yosemite specially left over):
- # -> x86_64-darwin [MacTeX]
- # 10.6/Snow Leopard through 10.10/Yosemite:
- # -> x86_64-darwinlegacy if 64-bit
+ # 10.x and newer -> x86_64-darwin [MacTeX]
+ # 10.6/Snow Leopard through 10.x -> x86_64-darwinlegacy, if 64-bit
+ # x changes every year. In 2020 (Big Sur) Apple started with 11.x.
#
# (BTW, uname -r numbers are larger by 4 than the Mac minor version.